@@ -15,6 +15,11 @@ sub run {
         @Starman::Server::ISA = qw(Net::Server::SS::PreFork); # Yikes.
     }
 
+    while (my($key, $value) = each %$self) {
+        $key =~ s/^net_server_// or next;
+        $self->{net_server_args}{$key} = $value;
+    }
+
     Starman::Server->new->run($app, {%$self});
 }
 
